==> google_cloud_network_services-0.2.1-py2.py3-none-any.whl: google/cloud/network_services_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .common import (
    EndpointMatcher,
    OperationMetadata,
    TrafficPortSelector,
)
from .endpoint_policy import (
    CreateEndpointPolicyRequest,
    DeleteEndpointPolicyRequest,
    EndpointPolicy,
    GetEndpointPolicyRequest,
    ListEndpointPoliciesRequest,
    ListEndpointPoliciesResponse,
    UpdateEndpointPolicyRequest,
)
from .gateway import (
    CreateGatewayRequest,
    DeleteGatewayRequest,
    Gateway,
    GetGatewayRequest,
    ListGatewaysRequest,
    ListGatewaysResponse,
    UpdateGatewayRequest,
)
from .grpc_route import (
    CreateGrpcRouteRequest,
    DeleteGrpcRouteRequest,
    GetGrpcRouteRequest,
    GrpcRoute,
    ListGrpcRoutesRequest,
    ListGrpcRoutesResponse,
    UpdateGrpcRouteRequest,
)
from .http_route import (
    CreateHttpRouteRequest,
    DeleteHttpRouteRequest,
    GetHttpRouteRequest,
    HttpRoute,
    ListHttpRoutesRequest,
    ListHttpRoutesResponse,
    UpdateHttpRouteRequest,
)
from .mesh import (
    CreateMeshRequest,
    DeleteMeshRequest,
    GetMeshRequest,
    ListMeshesRequest,
    ListMeshesResponse,
    Mesh,
    UpdateMeshRequest,
)
from .service_binding import (
    CreateServiceBindingRequest,
    DeleteServiceBindingRequest,
    GetServiceBindingRequest,
    ListServiceBindingsRequest,
    ListServiceBindingsResponse,
    ServiceBinding,
)
from .tcp_route import (
    CreateTcpRouteRequest,
    DeleteTcpRouteRequest,
    GetTcpRouteRequest,
    ListTcpRoutesRequest,
    ListTcpRoutesResponse,
    TcpRoute,
    UpdateTcpRouteRequest,
)
from .tls_route import (
    CreateTlsRouteRequest,
    DeleteTlsRouteRequest,
    GetTlsRouteRequest,
    ListTlsRoutesRequest,
    ListTlsRoutesResponse,
    TlsRoute,
    UpdateTlsRouteRequest,
)

__all__ = (
    "EndpointMatcher",
    "OperationMetadata",
    "TrafficPortSelector",
    "CreateEndpointPolicyRequest",
    "DeleteEndpointPolicyRequest",
    "EndpointPolicy",
    "GetEndpointPolicyRequest",
    "ListEndpointPoliciesRequest",
    "ListEndpointPoliciesResponse",
    "UpdateEndpointPolicyRequest",
    "CreateGatewayRequest",
    "DeleteGatewayRequest",
    "Gateway",
    "GetGatewayRequest",
    "ListGatewaysRequest",
    "ListGatewaysResponse",
    "UpdateGatewayRequest",
    "CreateGrpcRouteRequest",
    "DeleteGrpcRouteRequest",
    "GetGrpcRouteRequest",
    "GrpcRoute",
    "ListGrpcRoutesRequest",
    "ListGrpcRoutesResponse",
    "UpdateGrpcRouteRequest",
    "CreateHttpRouteRequest",
    "DeleteHttpRouteRequest",
    "GetHttpRouteRequest",
    "HttpRoute",
    "ListHttpRoutesRequest",
    "ListHttpRoutesResponse",
    "UpdateHttpRouteRequest",
    "CreateMeshRequest",
    "DeleteMeshRequest",
    "GetMeshRequest",
    "ListMeshesRequest",
    "ListMeshesResponse",
    "Mesh",
    "UpdateMeshRequest",
    "CreateServiceBindingRequest",
    "DeleteServiceBindingRequest",
    "GetServiceBindingRequest",
    "ListServiceBindingsRequest",
    "ListServiceBindingsResponse",
    "ServiceBinding",
    "CreateTcpRouteRequest",
    "DeleteTcpRouteRequest",
    "GetTcpRouteRequest",
    "ListTcpRoutesRequest",
    "ListTcpRoutesResponse",
    "TcpRoute",
    "UpdateTcpRouteRequest",
    "CreateTlsRouteRequest",
    "DeleteTlsRouteRequest",
    "GetTlsRouteRequest",
    "ListTlsRoutesRequest",
    "ListTlsRoutesResponse",
    "TlsRoute",
    "UpdateTlsRouteRequest",
)

==> google_cloud_network_services-0.5.4-py2.py3-none-any.whl: google/cloud/network_services_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .common import EndpointMatcher, OperationMetadata, TrafficPortSelector
from .endpoint_policy import (
    CreateEndpointPolicyRequest,
    DeleteEndpointPolicyRequest,
    EndpointPolicy,
    GetEndpointPolicyRequest,
    ListEndpointPoliciesRequest,
    ListEndpointPoliciesResponse,
    UpdateEndpointPolicyRequest,
)
from .gateway import (
    CreateGatewayRequest,
    DeleteGatewayRequest,
    Gateway,
    GetGatewayRequest,
    ListGatewaysRequest,
    ListGatewaysResponse,
    UpdateGatewayRequest,
)
from .grpc_route import (
    CreateGrpcRouteRequest,
    DeleteGrpcRouteRequest,
    GetGrpcRouteRequest,
    GrpcRoute,
    ListGrpcRoutesRequest,
    ListGrpcRoutesResponse,
    UpdateGrpcRouteRequest,
)
from .http_route import (
    CreateHttpRouteRequest,
    DeleteHttpRouteRequest,
    GetHttpRouteRequest,
    HttpRoute,
    ListHttpRoutesRequest,
    ListHttpRoutesResponse,
    UpdateHttpRouteRequest,
)
from .mesh import (
    CreateMeshRequest,
    DeleteMeshRequest,
    GetMeshRequest,
    ListMeshesRequest,
    ListMeshesResponse,
    Mesh,
    UpdateMeshRequest,
)
from .service_binding import (
    CreateServiceBindingRequest,
    DeleteServiceBindingRequest,
    GetServiceBindingRequest,
    ListServiceBindingsRequest,
    ListServiceBindingsResponse,
    ServiceBinding,
)
from .tcp_route import (
    CreateTcpRouteRequest,
    DeleteTcpRouteRequest,
    GetTcpRouteRequest,
    ListTcpRoutesRequest,
    ListTcpRoutesResponse,
    TcpRoute,
    UpdateTcpRouteRequest,
)
from .tls_route import (
    CreateTlsRouteRequest,
    DeleteTlsRouteRequest,
    GetTlsRouteRequest,
    ListTlsRoutesRequest,
    ListTlsRoutesResponse,
    TlsRoute,
    UpdateTlsRouteRequest,
)

__all__ = (
    "EndpointMatcher",
    "OperationMetadata",
    "TrafficPortSelector",
    "CreateEndpointPolicyRequest",
    "DeleteEndpointPolicyRequest",
    "EndpointPolicy",
    "GetEndpointPolicyRequest",
    "ListEndpointPoliciesRequest",
    "ListEndpointPoliciesResponse",
    "UpdateEndpointPolicyRequest",
    "CreateGatewayRequest",
    "DeleteGatewayRequest",
    "Gateway",
    "GetGatewayRequest",
    "ListGatewaysRequest",
    "ListGatewaysResponse",
    "UpdateGatewayRequest",
    "CreateGrpcRouteRequest",
    "DeleteGrpcRouteRequest",
    "GetGrpcRouteRequest",
    "GrpcRoute",
    "ListGrpcRoutesRequest",
    "ListGrpcRoutesResponse",
    "UpdateGrpcRouteRequest",
    "CreateHttpRouteRequest",
    "DeleteHttpRouteRequest",
    "GetHttpRouteRequest",
    "HttpRoute",
    "ListHttpRoutesRequest",
    "ListHttpRoutesResponse",
    "UpdateHttpRouteRequest",
    "CreateMeshRequest",
    "DeleteMeshRequest",
    "GetMeshRequest",
    "ListMeshesRequest",
    "ListMeshesResponse",
    "Mesh",
    "UpdateMeshRequest",
    "CreateServiceBindingRequest",
    "DeleteServiceBindingRequest",
    "GetServiceBindingRequest",
    "ListServiceBindingsRequest",
    "ListServiceBindingsResponse",
    "ServiceBinding",
    "CreateTcpRouteRequest",
    "DeleteTcpRouteRequest",
    "GetTcpRouteRequest",
    "ListTcpRoutesRequest",
    "ListTcpRoutesResponse",
    "TcpRoute",
    "UpdateTcpRouteRequest",
    "CreateTlsRouteRequest",
    "DeleteTlsRouteRequest",
    "GetTlsRouteRequest",
    "ListTlsRoutesRequest",
    "ListTlsRoutesResponse",
    "TlsRoute",
    "UpdateTlsRouteRequest",
)
